@@ -42,7 +42,6 @@
 #include <string.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 
 #if HAVE_EXEMPI
 #include <exempi/xmp.h>
@@ -52,20 +51,33 @@ static EogStartupFlags flags;
 
 static gboolean fullscreen = FALSE;
 static gboolean slide_show = FALSE;
-static gboolean disable_collection = FALSE;
+static gboolean disable_gallery = FALSE;
 #if HAVE_DBUS
 static gboolean force_new_instance = FALSE;
 #endif
 static gchar **startup_files = NULL;
 
+static gboolean
+_print_version_and_exit (const gchar *option_name,
+			 const gchar *value,
+			 gpointer data,
+			 GError **error)
+{
+	g_print("%s %s\n", _("Eye of GNOME Image Viewer"), VERSION);
+	exit (EXIT_SUCCESS);
+	return TRUE;
+}
+
 static const GOptionEntry goption_options[] =
 {
 	{ "fullscreen", 'f', 0, G_OPTION_ARG_NONE, &fullscreen, N_("Open in fullscreen mode"), NULL  },
-	{ "disable-image-collection", 'c', 0, G_OPTION_ARG_NONE, &disable_collection, N_("Disable image collection"), NULL  },
+	{ "disable-gallery", 'g', 0, G_OPTION_ARG_NONE, &disable_gallery, N_("Disable image gallery"), NULL  },
 	{ "slide-show", 's', 0, G_OPTION_ARG_NONE, &slide_show, N_("Open in slideshow mode"), NULL  },
 #if HAVE_DBUS
 	{ "new-instance", 'n', 0, G_OPTION_ARG_NONE, &force_new_instance, N_("Start a new instance instead of reusing an existing one"), NULL },
 #endif
+	{ "version", 0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
+	  _print_version_and_exit, N_("Show the application's version"), NULL},
 	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &startup_files, NULL, N_("[FILE…]") },
 	{ NULL }
 };
@@ -76,8 +88,8 @@ set_startup_flags (void)
   if (fullscreen)
     flags |= EOG_STARTUP_FULLSCREEN;
 
-  if (disable_collection)
-    flags |= EOG_STARTUP_DISABLE_COLLECTION;
+  if (disable_gallery)
+    flags |= EOG_STARTUP_DISABLE_GALLERY;
 
   if (slide_show)
     flags |= EOG_STARTUP_SLIDE_SHOW;
@@ -173,6 +185,8 @@ main (int argc, char **argv)
 	GError *error = NULL;
 	GOptionContext *ctx;
 
+	g_setenv ("GSETTINGS_BACKEND", "gconf", FALSE);
+
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
 
@@ -218,6 +232,9 @@ main (int argc, char **argv)
 
 #ifdef HAVE_EXEMPI
  	xmp_init();
+#endif
+#ifdef HAVE_RSVG
+	rsvg_init();
 #endif
 	eog_debug_init ();
 	eog_job_queue_init ();
@@ -245,6 +262,9 @@ main (int argc, char **argv)
 
 	eog_plugin_engine_shutdown ();
 
+#ifdef HAVE_RSVG
+	rsvg_term();
+#endif
 #ifdef HAVE_EXEMPI
 	xmp_terminate();
 #endif
